@@ -273,10 +273,17 @@ class PlaceService(BaseRdbmsService):
         """
         areas = AreaService().find_areas_with_ip_address(
             ip_address,
-            lowest_area_level=0,
+            lowest_area_level=4,  # @note: To get faster response time
             highest_area_level=0,
             locale=locale)
 
+        # Filter the country area.
+        areas = [
+            area
+            for area in areas
+            if area.level == 0
+        ]
+
         area = None if len(areas) == 0 else areas[0]
         return area
 
